<style>
    #django-app-flag {
        z-index:2147483644;
        position:fixed;
        bottom:8px;
        right:8px;
        background:#092e20;
        width:195px;
        color:white;
        box-shadow: 0px 5px 5px -5px #000;
        height:50px;
        border:1px solid #444;
        -webkit-border-radius:5px;
        -moz-border-radius:5px;
        border-radius:5px;
    }
    #django-app-flag img {
        margin:5px;
    }
    #django-app-flag span {
        float:right;
        font-family: 'Hevlvetica Neue', Helvetica, Arial, sans-serif;
        font-size:1em;
        font-weight:300;
        margin:15px 10px;
    }
</style>
<a href='https://www.djangoproject.com/' target='_blank' id='django-app-flag'>
    <img src='https://docs.djangoproject.com/s/img/site/hdr_logo.b19c5e60269d.gif' />
    <span>
        v{{version}}
    </span>
</div>
